@@ -2,7 +2,7 @@
 #
 # Workbook - A class for writing the Excel XLSX Workbook file.
 #
-# Copyright 2013-2017, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2018, John McNamara, jmcnamara@cpan.org
 #
 
 # Standard packages.
@@ -10,10 +10,11 @@ import sys
 import re
 import os
 import operator
+import time
 import warnings
 from warnings import warn
 from datetime import datetime
-from zipfile import ZipFile, ZIP_DEFLATED
+from zipfile import ZipFile, ZipInfo, ZIP_DEFLATED
 from struct import unpack
 
 from .compatibility import int_types, num_types, str_types, force_unicode
@@ -503,6 +504,21 @@ class Workbook(xmlwriter.XMLwriter):
         """
         return self.sheetnames.get(name)
 
+    def get_default_url_format(self):
+        """
+        Get the default url format used when a user defined format isn't
+        specified with write_url(). The format is the hyperlink style defined
+        by Excel for the default theme.
+
+        Args:
+            None.
+
+        Returns:
+            A format object.
+
+        """
+        return self.default_url_format
+
     def use_zip64(self):
         """
         Allow ZIP64 extensions when writing xlsx file zip container.
@@ -626,13 +642,19 @@ class Workbook(xmlwriter.XMLwriter):
         # Add XML sub-files to the Zip file with their Excel filename.
         for os_filename, xml_filename, is_binary in xml_files:
             if self.in_memory:
+
+                zipinfo = ZipInfo(xml_filename, (1980, 1, 1, 0, 0, 0))
                 if is_binary:
-                    xlsx_file.writestr(xml_filename, os_filename.getvalue())
+                    xlsx_file.writestr(zipinfo, os_filename.getvalue())
                 else:
-                    xlsx_file.writestr(xml_filename,
+                    xlsx_file.writestr(zipinfo,
                                        os_filename.getvalue().encode('utf-8'))
             else:
                 # The files are tempfiles.
+
+                timestamp = time.mktime((1980, 1, 1, 0, 0, 0, 0, 0, 0))
+                os.utime(os_filename, (timestamp, timestamp))
+
                 xlsx_file.write(os_filename, xml_filename)
                 os.remove(os_filename)
 
@@ -1224,19 +1246,22 @@ class Workbook(xmlwriter.XMLwriter):
         x_dpi = 96
         y_dpi = 96
 
-        # Search through the image data to read the height and width in the
-        # 0xFFC0/C2 element. Also read the DPI in the 0xFFE0 element.
+        # Search through the image data to read the JPEG markers.
         while not end_marker and offset < data_length:
 
             marker = (unpack('>H', data[offset + 0:offset + 2]))[0]
             length = (unpack('>H', data[offset + 2:offset + 4]))[0]
 
-            # Read the image dimensions.
-            if marker == 0xFFC0 or marker == 0xFFC2:
+            # Read the height and width in the 0xFFCn elements (except C4, C8
+            # and CC which aren't SOF markers).
+            if ((marker & 0xFFF0) == 0xFFC0
+                    and marker != 0xFFC4
+                    and marker != 0xFFC8
+                    and marker != 0xFFCC):
                 height = (unpack('>H', data[offset + 5:offset + 7]))[0]
                 width = (unpack('>H', data[offset + 7:offset + 9]))[0]
 
-            # Read the image DPI.
+            # Read the DPI in the 0xFFE0 element.
             if marker == 0xFFE0:
                 units = (unpack('b', data[offset + 11:offset + 12]))[0]
                 x_density = (unpack('>H', data[offset + 12:offset + 14]))[0]
